@@ -10,9 +10,8 @@
 
 #include <R.h>
 #include <Rmath.h>
-#include <Rinternals.h> 
-#include "Rinterface.h"
-#include <R_ext/Utils.h>  
+//#include <Rinternals.h> 
+//#include <R_ext/Utils.h>  
 
 define_exception_type(int);
 extern struct exception_context the_exception_context[1];
